Package: pfamAnalyzeR
Type: Package
Title: Identification of domain isotypes in pfam data
Version: 1.6.0
Authors@R: person(given="Kristoffer",family="Vitting-Seerup", role=c("cre","aut"),email="k.vitting.seerup@gmail.com",comment = c(ORCID = "0000-0002-6450-0608"))
Description: Protein domains is one of the most import annoation of proteins we have
    with the Pfam database/tool being (by far) the most used tool. This R package enables
    the user to read the pfam prediction from both webserver and stand-alone runs into R.
    We have recently shown most human protein domains exist as multiple distinct variants 
    termed domain isotypes. Different domain isotypes are used in a cell, tissue, and 
    disease-specific manner. Accordingly, we find that domain isotypes, compared to each other,
    modulate, or abolish the functionality of a protein domain. This R package enables the
    identification and classification of such domain isotypes from Pfam data.
License: MIT + file LICENSE
Depends: R (>= 4.3.0), readr, stringr, dplyr
Imports: utils, tibble, magrittr
Encoding: UTF-8
RoxygenNote: 7.2.1
Suggests: BiocStyle, knitr, rmarkdown
VignetteBuilder: knitr
biocViews: AlternativeSplicing, TranscriptomeVariant,
        BiomedicalInformatics, FunctionalGenomics, SystemsBiology,
        Annotation, FunctionalPrediction, GenePrediction, DataImport
BugReports: https://github.com/kvittingseerup/pfamAnalyzeR/issues
git_url: https://git.bioconductor.org/packages/pfamAnalyzeR
git_branch: RELEASE_3_20
git_last_commit: f54b196
git_last_commit_date: 2024-10-29
Repository: Bioconductor 3.20
Date/Publication: 2024-10-29
NeedsCompilation: no
Packaged: 2024-10-30 02:08:25 UTC; biocbuild
Author: Kristoffer Vitting-Seerup [cre, aut]
    (<https://orcid.org/0000-0002-6450-0608>)
Maintainer: Kristoffer Vitting-Seerup <k.vitting.seerup@gmail.com>
